@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @Package: hspylib.main.hspylib.core.crud.file
+   @Package: hspylib.main.hspylib.hspylib.crud.file
       @file: file_storage.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -30,7 +30,7 @@ class FileStorage:
     def load(self) -> None:
         """TODO"""
         mode = 'r+' if os.path.exists(self.filename) else 'w+'
-        with open(self.filename, mode) as f_local_db:
+        with open(self.filename, mode, encoding='utf-8') as f_local_db:
             lines = f_local_db.read()
             if lines:
                 saved_data = ast.literal_eval(lines)
@@ -39,11 +39,11 @@ class FileStorage:
 
     def commit(self) -> None:
         """TODO"""
-        with open(self.filename, 'w') as f_local_db:
+        with open(self.filename, 'w', encoding='utf-8') as f_local_db:
             f_local_db.write(str(self.data))
         log.debug("File storage filename=%s committed entries=%d", self.filename, len(self.data))
 
     def truncate(self) -> None:
         """TODO"""
-        open(self.filename, 'w').close()
-        log.warning("File storage filename=%s was truncated", self.filename)
+        with open(self.filename, 'w', encoding='utf-8'):
+            log.warning("File storage filename=%s was truncated", self.filename)
