@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.core.tools
+   @package: hspylib.main.hspylib.hspylib.tools
       @file: keyboard.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -16,8 +16,7 @@
 import select
 import string
 import sys
-import time
-from typing import Optional, Tuple
+from typing import Optional
 
 import getkey
 
