@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.modules.web
+   @package: hspylib.main.hspylib.modules.web
       @file: soap_utils.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -25,10 +24,10 @@ from hspylib.modules.fetch.http_response import HttpResponse
 
 
 def soap_call(
-        url: str,
-        method: HttpMethod,
-        data: str,
-        headers: Optional[CaseInsensitiveDict]) -> Optional[HttpResponse]:
+    url: str,
+    method: HttpMethod,
+    data: str,
+    headers: Optional[CaseInsensitiveDict]) -> Optional[HttpResponse]:
     """TODO"""
 
     all_headers = {} if not headers else headers
@@ -36,8 +35,8 @@ def soap_call(
         "Content-Type": "text/xml",
         "Accept": "*/*"
     })
-    log.info(f"Processing SOAP {all_headers} {method} -> {url} \n{data if data else '<None>'}")
+    log.info("Processing SOAP %s {method} -> %s \n%s", all_headers, url, data if data else '<None>')
     response = fetch(url=url, method=method, headers=all_headers, body=data)
-    log.info(f"Response <=  Status: {response.status_code}  Payload: {response.body if response.body else '<None>'}")
+    log.info("Response <=  Status: %s  Payload: %s", response.status_code, response.body if response.body else '<None>')
 
     return response
